@@ -57,7 +57,7 @@ def parse_args(default_db, default_chromecast=""):
     parser = argparse.ArgumentParser(formatter_class=argparse.ArgumentDefaultsHelpFormatter)
 
     parser.add_argument(
-        "db",
+        "database",
         nargs="?",
         default=default_db,
         help="Database file. If not specified a generic name will be used: audio.db, video.db, fs.db, etc",
@@ -200,10 +200,14 @@ Double spaces means one space
     parser.add_argument("--post-action", "--action", "-k", default="keep", help="Choose what to do after playing")
     parser.add_argument("--shallow-organize", default="/mnt/d/")
 
+    parser.add_argument('--db', '-db')
     parser.add_argument("--ignore-errors", "--ignoreerrors", action="store_true")
     parser.add_argument("--verbose", "-v", action="count", default=0)
     args = parser.parse_args()
 
+    if args.db:
+        args.database = args.db
+
     if args.limit == DEFAULT_PLAY_QUEUE and args.print:
         args.limit = None
     elif args.limit in ["inf", "all"]:
@@ -537,6 +541,7 @@ def construct_query(args):
     {args.sql_filter}
     {'and audio_count > 0' if args.action == Subcommand.listen else ''}
     {'and video_count > 0' if args.action == Subcommand.watch else ''}
+    {'and path not like "%/keep/%"' if args.post_action == 'askkeep' else ''}
     ORDER BY 1=1
         {',' + args.sort if args.sort else ''}
         {', path' if args.print or args.include or args.play_in_order > 0 else ''}
@@ -612,17 +617,18 @@ def printer(args, query, bindings):
         print(tabulate(tbl, tablefmt="fancy_grid", headers="keys", showindex=False))  # type: ignore
 
         if args.action != Subcommand.filesystem:
-            print(f'{len(db_resp)} items')
+            if len(db_resp) > 1:
+                print(f'{len(db_resp)} items')
             summary = db_resp.sum(numeric_only=True)
             duration = summary.get("duration") or 0
-            duration = timedelta(seconds=duration)  # type: ignore
-            print("Total duration:", humanize.precisedelta(duration, minimum_unit="minutes"))
+            duration = human_time(duration)
+            print("Total duration:", duration)
 
     exit()
 
 
 def process_actions(args):
-    args.con = sqlite_con(args.db)
+    args.con = sqlite_con(args.database)
     query, bindings = construct_query(args)
 
     if args.print:
